==> humhub-1.14.5.tar.gz: humhub-1.14.5/protected/humhub/modules/user/messages/lt/auth.php <==
<?php
return array (
  '<strong>Account</strong> registration' => '<strong>Paskyros</strong> registracija',
  '<strong>Change</strong> Password' => '',
  '<strong>Change</strong> your password' => '<strong>Pakeisti</strong> slaptažodį',
  '<strong>Join</strong> the network' => '',
  '<strong>Password</strong> changed!' => '<strong>Slaptažodis</strong> pakeistas!',
  '<strong>Password</strong> recovery' => '<strong>Slaptažodžio</strong> atnaujinimas',
  '<strong>Password</strong> recovery!' => '<strong>Slaptažodžio</strong> atnaujinimas!',
  '<strong>Please</strong> sign in' => '<strong>Prašome</strong> prisijungti',
  '<strong>Registration</strong> successful!' => '<strong>Registracija</strong</ sėkminga!',
  '<strong>Sign</strong> up' => '<strong>Užsiregistruokite</strong> ',
  '<strong>Your account</strong> has been successfully created!' => '<strong>Jūsų paskyra</strong> sėkmingai sukurta!',
  'Account' => 'Paskyra',
  'After activating your account by the administrator, you will receive a notification by email.' => 'Kai administratorius aktyvuos Jūsų anketą, elektroniniu paštu Jums bus atsiųstas pranešimas.',
  'Back' => 'Atgal',
  'Change password' => 'Pakeisti slaptažodį',
  'Confirm' => 'Patvirtinti',
  'Create Account' => '',
  'Create account' => 'Sukurti paskyrą',
  'Don\'t have an account? Join the network by entering your e-mail address.' => 'Neturite paskyros? Prisijunkite prie tinklo įvesdami savo elektroninio pašto adresą.',
  'Due to security reasons you are required to change your password in order to access the platform.' => '',
  'Enter security code above' => 'žemiau įveskite apsaugos kodą',
  'Forgot your password?' => 'Pamiršote slaptažodį?',
  'Go to login page' => 'Eikite į registracijos puslapį',
  'Group' => 'Grupė',
  'Hello {displayName}' => 'Sveiki {displayName}',
  'Hello {displayName},' => 'Sveiki {displayName} ,',
  'If you don\'t use this link within 24 hours, it will expire.' => 'Jei nepasinaudosite šia nuoroda per 24 valandas, ji baigs galioti.',
  'If you\'re already a member, please login with your username/email and password.' => 'Jei Jūs jau esate nariu, prašome prisijungti su savo vartotojo vardu/elektroninio pašto adresu ir slaptažodžiu.',
  'Just enter your e-mail address. We\'ll send you recovery instructions!' => 'Tiesiog įveskite savo elektroninio pašto adresą. Mes Jums atsiųsime atnaujinimo instrukcijas!',
  'Log out' => '',
  'Login' => 'Prisijungti',
  'New user needs approval' => 'Naujam vartotojui reikia patvirtinimo',
  'Password recovery' => '',
  'Password reset' => '',
  'Please check your email and follow the instructions!' => 'Prašome patikrinti savo elektroninį paštą ir sekite instrukcijas!',
  'Please click on the link below to view request:' => '',
  'Please enter the letters from the image.' => '',
  'Please login with your username/email and password.' => '',
  'Please use the following link within the next day to reset your password.' => 'Norint atnaujinti savo slaptažodį, prašome iki kitos dienos pasinaudoti šia nuoroda.',
  'Please wait' => '',
  'Register' => 'Registruotis',
  'Registration successful' => '',
  'Remember me' => '',
  'Reset Password' => 'Atnaujinti slaptažodį',
  'Reset password' => 'Iš naujo nustatyti slaptažodį',
  'Sign in' => 'Prisijungti',
  'To log in with your new account, click the button below.' => 'Norint prisiregistruoti naująja paskyra, paspauskite žemiau esantį mygtuką.',
  'User or Password incorrect.' => '',
  'We’ve sent you an email containing a link that will allow you to reset your password.' => 'Mes Jums išsiuntėme elektroninį laišką su nuoroda, kuri leis atnaujinti slaptažodį.',
  'Your email' => 'Jūsų elektroninio pašto adresas',
  'Your password' => 'Jūsų slaptažodis',
  'Your password has been successfully changed!' => 'Jūsų slaptažodis sėkmingai pakeistas!',
  'Your password is incorrect!' => 'Jūsų slaptažodis yra neteisingas!',
  'a new user {displayName} needs approval.' => '',
  'back to home' => 'atgal į namų puslapį',
  'email' => 'elektroninio pašto adresas',
  'password' => 'slaptažodis',
  'username or email' => 'vartotojo vardas arba elektroninio pašto adresas',
);

==> humhub-1.16.2.tar.gz: humhub-1.16.2/protected/humhub/modules/user/messages/lt/auth.php <==
<?php
return array (
  '<strong>Account</strong> registration' => '<strong>Paskyros</strong> registracija',
  '<strong>Change</strong> Password' => '<strong>Keisti</strong> Slaptažodį',
  '<strong>Change</strong> your password' => '<strong>Pakeisti</strong> slaptažodį',
  '<strong>Join</strong> the network' => '<strong>Prisijungti</strong> į tinklą',
  '<strong>Password</strong> changed!' => '<strong>Slaptažodis</strong> pakeistas!',
  '<strong>Password</strong> recovery' => '<strong>Slaptažodžio</strong> atnaujinimas',
  '<strong>Password</strong> recovery!' => '<strong>Slaptažodžio</strong> atnaujinimas!',
  '<strong>Please</strong> sign in' => '<strong>Prašome</strong> prisijungti',
  '<strong>Registration</strong> successful!' => '<strong>Registracija</strong>sėkminga!',
  '<strong>Sign</strong> up' => '<strong>Užsiregistruokite</strong>',
  '<strong>Your account</strong> has been successfully created!' => '<strong>Jūsų paskyra</strong> sėkmingai sukurta!',
  'Account' => 'Paskyra',
  'After activating your account by the administrator, you will receive a notification by email.' => 'Kai administratorius aktyvuos Jūsų anketą, elektroniniu paštu Jums bus atsiųstas pranešimas.',
  'Back' => 'Atgal',
  'Change password' => 'Pakeisti slaptažodį',
  'Confirm' => 'Patvirtinti',
  'Create Account' => 'Sukurti Paskyrą',
  'Create account' => 'Sukurti paskyrą',
  'Don\'t have an account? Join the network by entering your e-mail address.' => 'Neturite paskyros? Prisijunkite prie tinklo įvesdami savo elektroninio pašto adresą.',
  'Due to security reasons you are required to change your password in order to access the platform.' => 'Dėl saugumo sumetimų, norėdami prisijungti prie platformos, turite pasikeisti slaptažodį.',
  'Enter security code above' => 'žemiau įveskite apsaugos kodą',
  'Forgot your password?' => 'Pamiršote slaptažodį?',
  'Go to login page' => 'Eikite į registracijos puslapį',
  'Group' => 'Grupė',
  'Hello {displayName}' => 'Sveiki {displayName}',
  'Hello {displayName},' => 'Sveiki {displayName} ,',
  'If you don\'t use this link within 24 hours, it will expire.' => 'Jei nepasinaudosite šia nuoroda per 24 valandas, ji baigs galioti.',
  'If you\'re already a member, please login with your username/email and password.' => 'Jei Jūs jau esate nariu, prašome prisijungti su savo vartotojo vardu/elektroninio pašto adresu ir slaptažodžiu.',
  'Just enter your e-mail address. We\'ll send you recovery instructions!' => 'Tiesiog įveskite savo elektroninio pašto adresą. Mes Jums atsiųsime atnaujinimo instrukcijas!',
  'Log out' => 'Atsijungti',
  'Login' => 'Prisijungti',
  'New user needs approval' => 'Naujam vartotojui reikia patvirtinimo',
  'Password recovery' => 'Slaptažodžio atkūrimas',
  'Password reset' => 'Slaptažodžio atkūrimas',
  'Please check your email and follow the instructions!' => 'Prašome patikrinti savo elektroninį paštą ir sekite instrukcijas!',
  'Please click on the link below to view request:' => 'Spustelėkite toliau pateiktą nuorodą ir peržiūrėkite užklausą:',
  'Please enter the letters from the image.' => 'Suveskite raides',
  'Please login with your username/email and password.' => 'Prašome prisijungti su vartotojo vardu arba el. paštu ir slaptažodžiu',
  'Please use the following link within the next day to reset your password.' => 'Norint atnaujinti savo slaptažodį, prašome iki kitos dienos pasinaudoti šia nuoroda.',
  'Please wait' => 'Prašome palaukti',
  'Register' => 'Registruotis',
  'Registration successful' => 'Registracija sėkminga',
  'Remember me' => 'Prisiminti mane',
  'Reset Password' => 'Atnaujinti slaptažodį',
  'Reset password' => 'Iš naujo nustatyti slaptažodį',
  'Sign in' => 'Prisijungti',
  'To log in with your new account, click the button below.' => 'Norint prisiregistruoti naująja paskyra, paspauskite žemiau esantį mygtuką.',
  'User or Password incorrect.' => 'Vartotojo vardas arba slaptažodis neteisingas',
  'We’ve sent you an email containing a link that will allow you to reset your password.' => 'Mes Jums išsiuntėme elektroninį laišką su nuoroda, kuri leis atnaujinti slaptažodį.',
  'Your email' => 'Jūsų elektroninio pašto adresas',
  'Your password' => 'Jūsų slaptažodis',
  'Your password has been successfully changed!' => 'Jūsų slaptažodis sėkmingai pakeistas!',
  'Your password is incorrect!' => 'Jūsų slaptažodis yra neteisingas!',
  'a new user {displayName} needs approval.' => '{displayName} laukia patvirtinimo',
  'back to home' => 'atgal į namų puslapį',
  'Password' => 'slaptažodis',
  'Username or Email' => 'vartotojo vardas arba elektroninio pašto adresas',
);
